@echo off

:::::::::::::::::::::::
:: option parsing
:::::::::::::::::::::

:: default values
set lineflag=0
set viewflag=0
set renderflag=0
set simflag=0
set filename="out"

:GETOPTS
 if /I %1 == -l set lineflag=1
 if /I %1 == -v set viewflag=1
 if /I %1 == -r set renderflag=1
 if /I %1 == -s set simflag=1
 if /I %1 == -f set filename=%2& shift
 if /I %1 == -h goto USAGE
 shift
if /I %1 == -l goto GETOPTS
if /I %1 == -v goto GETOPTS
if /I %1 == -r goto GETOPTS
if /I %1 == -s goto GETOPTS
if /I %1 == -f goto GETOPTS
if /I %1 == -h goto GETOPTS

:: so how many flags remain
echo First remaining argument is: 
echo %1

:: level to lessen priority to leave processor time to applet realtime 
:: START /b /low or /belownormal   ...
:: see below

:: do what is requested
:TEST
if %lineflag% EQU 1 goto LINE
if %viewflag% EQU 1 goto VIEW
if %renderflag% EQU 1 goto RENDER
if %simflag% EQU 1 goto SIM
goto done

:::::::::::::::::::::
:: display usage
:::::::::::::::::::::
:USAGE
ECHO usage: $0 options
ECHO
ECHO This is the ANAR+ radiance rendering and simulation script 
ECHO 
ECHO OPTIONS:
ECHO	-h	
ECHO		Show this message
ECHO	-l
ECHO		generates 4 views in vector (.eps) format
ECHO	-v
ECHO		generates a 4 view image
ECHO	-r   
ECHO		generates radiance rendering (using rpict)
ECHO	-s  
ECHO   		radiance simulation (using rtrace and input measuring points)  	 
ECHO	-f filename      
ECHO   		specifies optional filename
ECHO
exit



:::::::::::::::::::::
:: 4 views images
:::::::::::::::::::::

:LINE
:: produces a 4 views line drawing in eps
C:\Radiance\bin\objline %filename%.rad | psmeta > %filename%4.eps
set lineflag=0
goto TEST

:VIEW
:: produces a 4 views image
C:\Radiance\bin\objpict sky.rad material.rad %filename%.rad > %filename%4.hdr
:: convert the 4 view image
C:\Radiance\bin\ra_tiff param %filename%4.hdr %filename%4.tif
set viewflag=0
goto TEST

:::::::::::::::::::::
:: rendering
:::::::::::::::::::::

:RENDER
:: note that parameters can now be used as normal since parameters were shifted above
:: %1 = render directory
:: %2 = superposition flag for irradiance countour lines
:: $3 = mkillum flag for secondary sources computation
if (%3)==() ECHO radiance render usage: radiance.bat -r -f filename dir superposeFlag mkillumFlag & exit

:: move to render dir
chdir %1
echo local path %cd%
echo batch path %~dp0

:: compute octree
C:\Radiance\bin\oconv sky.rad  material.rad %filename%.rad > %filename%.oct


:: mkillum computation for secondary sources if requested
if %3 EQU 1 ( 
	  echo mkillum computation
	  C:\Radiance\bin\mkillum param %filename%.oct < %filename%.rad > i%filename%.rad
	  C:\Radiance\bin\oconv -i %filename%.oct i%filename%.rad > i%filename%.oct
)

echo rendering
:: render image with correct viewpoint
if %3 EQU 1 (
	C:\Radiance\bin\rpict param -vf %filename%.vp i%filename%.oct > %filename%.hdr
) else ( 
	C:\Radiance\bin\rpict param -vf %filename%.vp %filename%.oct > %filename%.hdr
)
:: START /b /low

echo filtering
:: filter image
C:\Radiance\bin\pfilt param %filename%.hdr > %filename%_f.hdr


:: if superposition required generate irradiance picture
if %2 EQU 1 ( 
	  echo superposition rendering + filtering
	  C:\Radiance\bin\rpict paramSuper -vf %filename%.vp %filename%.oct > %filename%_sup.hdr
	  C:\Radiance\bin\pfilt param %filename%_sup.hdr > %filename%_supf.hdr
)

:: create false color image
:: if superposition required generate false color image super-imposed on regular image
if  %2 EQU 1 ( 
	echo superposition false color
	C:\Radiance\bin\falsecolor param -p %filename%_supf.hdr -i %filename%_f.hdr > %filename%_falseCL.hdr
) else (  
	echo false color 
	C:\Radiance\bin\falsecolor param -ip %filename%_f.hdr > %filename%_false.hdr
)

echo converting images
:: convert image in tif and gif
C:\Radiance\bin\ra_tiff param %filename%_f.hdr %filename%.tif
C:\Radiance\bin\ra_gif param %filename%_f.hdr %filename%.gif
if  %2 EQU 1 ( 
	C:\Radiance\bin\ra_tiff param %filename%_falseCL.hdr %filename%_falseCL.tif
	C:\Radiance\bin\ra_gif param %filename%_falseCL.hdr %filename%_falseCL.gif
) else (  
	C:\Radiance\bin\ra_tiff param %filename%_false.hdr %filename%_false.tif
	C:\Radiance\bin\ra_gif param %filename%_false.hdr %filename%_false.gif
)

:: open images
:: not currently working, apparently possible using 
:: "rundll32.exe C:\WINDOWS\System32\shimgvw.dll,ImageView_Fullscreen path-to-picture"
::C:\Radiance\bin\winimage %filename%_f.hdr
::if  %2 EQU 1 ( 
::	C:\Radiance\bin\winimage %filename%_falseCL.hdr
::) else (  
::	C:\Radiance\bin\winimage %filename%_false.hdr
::)

set renderflag=0
goto TEST

:::::::::::::::::::::::::::::
:: simulation (using rtrace)
:::::::::::::::::::::::::::::

:SIM
:: note that parameters can now be used as normal since $OPTIND rewinded above
:: %1 = iteration number
:: %2 = simulation directory
if (%2)==() ECHO radiance simulation usage: radiance.bat -s -f filename iterationNo dir & exit

:: temp dir for potentially changing files
set tmp=tmp

:: move to simulation dir
chdir %2
echo local path %cd%
echo batch path %~dp0

:: conversion in octree for radiance calculation 
C:\Radiance\bin\oconv sky.rad  material.rad %tmp%\%filename%_%1.rad > %tmp%\%filename%_%1.oct

:: calculation
C:\Radiance\bin\rtrace param %tmp%\%filename%_%1.oct < %tmp%\%filename%.inp > %tmp%\%filename%_%1.out
::START /b /low C:\Radiance\bin\rtrace param %tmp%\%filename%_%1.oct < %tmp%\%filename%.inp > %tmp%\%filename%_%1.out
::C:\Radiance\bin\rtrace -h -w -I -ab 1 -ad 1000 -as 250 -dc .9 -dj .66 %tmpr%\%filename%_%1.oct < %tempFolder%\%filename%.inp > %tmp%\%filename%_%1.out
set simflag=0
goto TEST

:done
exit